==> politicsnlp-0.0.13.tar.gz: politicsnlp-0.0.13/README.md <==
# Python Narrative packages
- [politicsnlp](https://pypi.org/project/politicsnlp/) for Politics
- [religionnlp](https://pypi.org/project/religionnlp/) for Religion
- [lawnlp](https://pypi.org/project/lawnlp/) for Law
- [economynlp](https://pypi.org/project/economynlp/) for Economy
- [cpanlp](https://pypi.org/project/cpanlp/) for Business
- [cpanlp](https://pypi.org/project/militarynlp/) for Military

## Communicate effectively within a common Political framework
 <img src="https://raw.githubusercontent.com/python-narrative/politicsnlp/main/politics.jpg" width = "220" height = "100" alt="logo" align=center />

For detailed installation instructions, see the
[documentation](https://cpanlp.com/documentation).

```python
pip install politicsnlp
import politicsnlp as poli
```

## Module:
|  Module   | Content  |
|  :----:  | :----:  |
| **Core**  | `Democracy`，`Freedom`，`Justice`，`Spirit Of The Law`，`Natural Rights`，`Separation Of Powers`|
| **Form Of Government**  | `Aristocracy`，`Autocracy`，`Colonialism`，`Communism`，`Direct Democracy`，`Monarchy`，`Oligarchy`，`Representative Democracy`，`Socialism`，`Theocracy`|
| **Ideology**  | `Confucianism`，`Nationalism`|
| **Individual**  | `Civil Servant`，`Monarch`，`Strongman`，`Tyrant`|
| **Institutions**  | `Administration`，`Judiciary`，`Legislature`|
| **Marxism**  | `Marxism`，`Mao Zedong Thought`，`Deng Xiaoping Theory`，`Xi Jinping Thought`|
| **Party**  | `Conservative Party`，`CCP`，`UKIP`|
| **Stance**  | `Hawk`，`Leftist`，`Rightist`，`Neutral`|




Check out: https://cpanlp.com

==> politicsnlp-0.0.16.tar.gz: politicsnlp-0.0.16/README.md <==
# Python Narrative packages
- [politicsnlp](https://pypi.org/project/politicsnlp/) for Politics
- [religionnlp](https://pypi.org/project/religionnlp/) for Religion
- [lawnlp](https://pypi.org/project/lawnlp/) for Law
- [economynlp](https://pypi.org/project/economynlp/) for Economy
- [cpanlp](https://pypi.org/project/cpanlp/) for Business
- [militarynlp](https://pypi.org/project/militarynlp/) for Military

## Communicate effectively in Politics like a 🤖️
 <img src="https://raw.githubusercontent.com/python-narrative/politicsnlp/main/politics.jpg" width = "220" height = "100" alt="logo" align=center />

For detailed installation instructions, see the
[documentation](https://cpanlp.com/documentation).

```python
pip install politicsnlp
import politicsnlp as poli
```

## Module:
|  Module   | Content  |
|  :----:  | :----:  |
| **Core**  | `Democracy`，`Freedom`，`Justice`，`Spirit Of The Law`，`Natural Rights`，`Separation Of Powers`|
| **Form Of Government**  | `Aristocracy`，`Autocracy`，`Colonialism`，`Communism`，`Direct Democracy`，`Monarchy`，`Oligarchy`，`Representative Democracy`，`Socialism`，`Theocracy`|
| **Ideology**  | `Confucianism`，`Nationalism`|
| **Individual**  | `Civil Servant`，`Monarch`，`Strongman`，`Tyrant`|
| **Institutions**  | `Administration`，`Judiciary`，`Legislature`|
| **Marxism**  | `Marxism`，`Mao Zedong Thought`，`Deng Xiaoping Theory`，`Xi Jinping Thought`|
| **Party**  | `Conservative Party`，`CCP`，`UKIP`|
| **Stance**  | `Hawk`，`Leftist`，`Rightist`，`Neutral`|




Check out: https://cpanlp.com
